from .dynamical_systems import *
from .model import *
from .functions import *

__version__ = "0.0.1"
